import type { TableData, BaseFieldInfo } from '@/types/Tables/table'
import axiosInstance from '@/utils/axios/axiosInstance'
export function useTable() {
  const getData = async (
    url: string,
    config: Object = {},
  ): Promise<Array<TableData>> => {
    try {
      const res = await axiosInstance.get(url, config)
      console.log(res)
      if (res.status !== 0) throw new Error('请求失败')
      return res.data as TableData[]
    } catch {
      console.log('数据请求失败')
      return []
    }
  }

  /**
   * @description: 判断当前字段是否是需要固定的字段
   * @param {*} info 字段信息
   * @return {boolean}
   */
  const isFixedField = (
    fixedFields: Array<string>,
    info: BaseFieldInfo,
  ): boolean => {
    return fixedFields.includes(info.name)
  }

  return {
    getData,
    isFixedField,
  }
}
